@@ -11,9 +11,6 @@ pub(crate) struct Node {
     pub children: FxHashMap<char, Node>,
     pub(crate) weights: [i8; 4],
     pub depth: u8,
-    #[allow(dead_code)]
-    #[cfg(debug_assertions)]
-    pub phrase: &'static str,
 }
 
 impl Tree {
@@ -25,8 +22,6 @@ impl Tree {
                 children: FxHashMap::default(),
                 weights: [0; 4],
                 depth: (i + 1) as u8,
-                #[cfg(debug_assertions)]
-                phrase: &word[0..=i],
             });
         }
         current.weights = weights;
@@ -40,8 +35,6 @@ impl FromIterator<(&'static str, [i8; 4])> for Tree {
                 children: FxHashMap::default(),
                 weights: [0; 4],
                 depth: 0,
-                #[cfg(debug_assertions)]
-                phrase: "",
             },
         };
         for (word, weights) in iter.into_iter() {
